# ALMA Data Reduction Script

# Calibration

thesteps = []
step_title = {0: 'Import of the ASDM',
              1: 'Fix of SYSCAL table times',
              2: 'listobs',
              3: 'A priori flagging',
              4: 'Generation and time averaging of the WVR cal table',
              5: 'Generation of the Tsys cal table',
              6: 'Generation of the antenna position cal table',
              7: 'Application of the WVR, Tsys and antpos cal tables',
              8: 'Split out science SPWs and time average',
              9: 'Listobs, and save original flags',
              10: 'Initial flagging',
              11: 'Putting a model for the flux calibrator(s)',
              12: 'Save flags before bandpass cal',
              13: 'Bandpass calibration',
              14: 'Save flags before gain cal',
              15: 'Gain calibration',
              16: 'Save flags before applycal',
              17: 'Application of the bandpass and gain cal tables',
              18: 'Split out corrected column',
              19: 'Save flags after applycal'}

if 'applyonly' not in globals(): applyonly = True
try:
  print 'List of steps to be executed ...', mysteps
  thesteps = mysteps
except:
  print 'global variable mysteps not set.'
if (thesteps==[]):
  thesteps = range(0,len(step_title))
  print 'Executing all steps: ', thesteps

# The Python variable 'mysteps' will control which steps
# are executed when you start the script using
#   execfile('scriptForCalibration.py')
# e.g. setting
#   mysteps = [2,3,4]# before starting the script will make the script execute
# only steps 2, 3, and 4
# Setting mysteps = [] will make it execute all steps.

import re

import os

import casadef

if applyonly != True: es = aU.stuffForScienceDataReduction() 


if re.search('^4.7.2', casadef.casa_version) == None:
 sys.exit('ERROR: PLEASE USE THE SAME VERSION OF CASA THAT YOU USED FOR GENERATING THE SCRIPT: 4.7.2')


# CALIBRATE_AMPLI: 
# CALIBRATE_ATMOSPHERE: HL Tau,J0510+1800
# CALIBRATE_BANDPASS: J0510+1800
# CALIBRATE_DIFFGAIN: 
# CALIBRATE_FLUX: J0510+1800
# CALIBRATE_FOCUS: 
# CALIBRATE_PHASE: J0431+2037
# CALIBRATE_POINTING: J0510+1800
# OBSERVE_CHECK: J0426+2327
# OBSERVE_TARGET: HL Tau

# Using reference antenna = DV19

# Import of the ASDM
mystep = 0
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  if os.path.exists('uid___A002_Xace764_Xa09.ms') == False:
    importasdm('uid___A002_Xace764_Xa09', asis='Antenna Station Receiver Source CalAtmosphere CalWVR CorrelatorMode SBSummary', bdfflags=True, lazy=False, process_caldevice=False)
    if not os.path.exists('uid___A002_Xace764_Xa09.ms.flagversions'):
      print 'ERROR in importasdm. Output MS is probably not useful. Will stop here.'
      thesteps = []
  if applyonly != True: es.fixForCSV2555('uid___A002_Xace764_Xa09.ms')

# Fix of SYSCAL table times
mystep = 1
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  from recipes.almahelpers import fixsyscaltimes
  fixsyscaltimes(vis = 'uid___A002_Xace764_Xa09.ms')

print "# A priori calibration"

# listobs
mystep = 2
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.listobs')
  listobs(vis = 'uid___A002_Xace764_Xa09.ms',
    listfile = 'uid___A002_Xace764_Xa09.ms.listobs')
  
  

# A priori flagging
mystep = 3
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  flagdata(vis = 'uid___A002_Xace764_Xa09.ms',
    mode = 'manual',
    spw = '5~12,17~24',
    autocorr = True,
    flagbackup = False)
  
  flagdata(vis = 'uid___A002_Xace764_Xa09.ms',
    mode = 'manual',
    intent = '*POINTING*,*ATMOSPHERE*',
    flagbackup = False)
  
  flagcmd(vis = 'uid___A002_Xace764_Xa09.ms',
    inpmode = 'table',
    useapplied = True,
    action = 'plot',
    plotfile = 'uid___A002_Xace764_Xa09.ms.flagcmd.png')
  
  flagcmd(vis = 'uid___A002_Xace764_Xa09.ms',
    inpmode = 'table',
    useapplied = True,
    action = 'apply')
  

# Generation and time averaging of the WVR cal table
mystep = 4
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.wvr') 
  
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.wvrgcal') 
  
  mylogfile = casalog.logfile()
  casalog.setlogfile('uid___A002_Xace764_Xa09.ms.wvrgcal')
  
  wvrgcal(vis = 'uid___A002_Xace764_Xa09.ms',
    caltable = 'uid___A002_Xace764_Xa09.ms.wvr',
    spw = [17, 19, 21, 23],
    toffset = 0,
    tie = ['HL Tau,J0431+2037', 'J0426+2327,J0431+2037'],
    statsource = 'HL Tau')
  
  casalog.setlogfile(mylogfile)
  
  if applyonly != True: aU.plotWVRSolutions(caltable='uid___A002_Xace764_Xa09.ms.wvr', spw='17', antenna='DV19',
    yrange=[-199,199],subplot=22, interactive=False,
    figfile='uid___A002_Xace764_Xa09.ms.wvr.plots/uid___A002_Xace764_Xa09.ms.wvr') 
  
  #Note: If you see wraps in these plots, try changing yrange or unwrap=True 
  #Note: If all plots look strange, it may be a bad WVR on the reference antenna.
  #      To check, you can set antenna='' to show all baselines.
  

# Generation of the Tsys cal table
mystep = 5
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.tsys') 
  gencal(vis = 'uid___A002_Xace764_Xa09.ms',
    caltable = 'uid___A002_Xace764_Xa09.ms.tsys',
    caltype = 'tsys')
  
  # Flagging edge channels
  
  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.tsys',
    mode = 'manual',
    spw = '17:0~3;124~127,19:0~3;124~127,21:0~3;124~127,23:0~3;124~127',
    flagbackup = False)
  
  if applyonly != True: aU.plotbandpass(caltable='uid___A002_Xace764_Xa09.ms.tsys', overlay='time', 
    xaxis='freq', yaxis='amp', subplot=22, buildpdf=False, interactive=False,
    showatm=True,pwv='auto',chanrange='92.1875%',showfdm=True, showBasebandNumber=True, showimage=False, 
    field='', figfile='uid___A002_Xace764_Xa09.ms.tsys.plots.overlayTime/uid___A002_Xace764_Xa09.ms.tsys') 
  
  
  if applyonly != True: es.checkCalTable('uid___A002_Xace764_Xa09.ms.tsys', msName='uid___A002_Xace764_Xa09.ms', interactive=False) 
  

# Generation of the antenna position cal table
mystep = 6
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  # Warning: no baseline run found for following antenna(s): ['DV02'].
  
  # Note: the correction for antenna DA48 is larger than 2mm.
  
  # Position for antenna DA48 is derived from baseline run made on 2015-12-09 08:12:44.
  
  # Position for antenna DA44 is derived from baseline run made on 2015-12-09 08:12:44.
  
  # Position for antenna DV15 is derived from baseline run made on 2015-12-09 08:12:44.
  
  # Position for antenna DA43 is derived from baseline run made on 2015-12-09 08:12:44.
  
  # Position for antenna DA51 is derived from baseline run made on 2015-12-09 08:12:44.
  
  # Position for antenna DA56 is derived from baseline run made on 2015-12-09 08:12:44.
  
  # Position for antenna DA58 is derived from baseline run made on 2015-12-17 08:10:22.
  
  # Position for antenna DV01 is derived from baseline run made on 2015-12-09 08:12:44.
  
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.antpos') 
  gencal(vis = 'uid___A002_Xace764_Xa09.ms',
    caltable = 'uid___A002_Xace764_Xa09.ms.antpos',
    caltype = 'antpos',
    antenna = 'DA43,DA44,DA48,DA51,DA56,DA58,DV01,DV15',
  #  parameter = [0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0])
    parameter = [6.49567e-04,-5.10257e-04,-5.50931e-04,4.89653e-04,-8.19652e-04,-3.45365e-04,4.18002e-04,-2.79948e-03,-1.17591e-03,6.47600e-04,-4.68175e-04,-1.16381e-03,3.95307e-04,-9.22035e-04,-2.67195e-04,-2.68581e-04,6.75504e-04,5.71672e-04,-1.13800e-03,-3.29570e-04,5.54690e-05,3.04411e-04,1.56498e-04,-6.01937e-04])
  
  
  # antenna x_offset y_offset z_offset total_offset baseline_date
  # DA48     4.18002e-04   -2.79948e-03   -1.17591e-03    3.06506e-03      2015-12-09 08:12:44
  # DA51     6.47600e-04   -4.68175e-04   -1.16381e-03    1.41175e-03      2015-12-09 08:12:44
  # DV01    -1.13800e-03   -3.29570e-04    5.54690e-05    1.18606e-03      2015-12-09 08:12:44
  # DA56     3.95307e-04   -9.22035e-04   -2.67195e-04    1.03818e-03      2015-12-09 08:12:44
  # DA44     4.89653e-04   -8.19652e-04   -3.45365e-04    1.01532e-03      2015-12-09 08:12:44
  # DA43     6.49567e-04   -5.10257e-04   -5.50931e-04    9.92887e-04      2015-12-09 08:12:44
  # DA58    -2.68581e-04    6.75504e-04    5.71672e-04    9.24797e-04      2015-12-17 08:10:22
  # DV15     3.04411e-04    1.56498e-04   -6.01937e-04    6.92449e-04      2015-12-09 08:12:44
  

# Application of the WVR, Tsys and antpos cal tables
mystep = 7
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  
  from recipes.almahelpers import tsysspwmap
  tsysmap = tsysspwmap(vis = 'uid___A002_Xace764_Xa09.ms', tsystable = 'uid___A002_Xace764_Xa09.ms.tsys', tsysChanTol = 1)
  
  
  
  applycal(vis = 'uid___A002_Xace764_Xa09.ms',
    field = '0',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_Xace764_Xa09.ms.tsys', 'uid___A002_Xace764_Xa09.ms.wvr', 'uid___A002_Xace764_Xa09.ms.antpos'],
    gainfield = ['0', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  # Note: J0431+2037 didn't have any Tsys measurement, so I used the one made on HL Tau. This is probably Ok.
  
  applycal(vis = 'uid___A002_Xace764_Xa09.ms',
    field = '1',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_Xace764_Xa09.ms.tsys', 'uid___A002_Xace764_Xa09.ms.wvr', 'uid___A002_Xace764_Xa09.ms.antpos'],
    gainfield = ['3', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  # Note: J0426+2327 didn't have any Tsys measurement, so I used the one made on HL Tau. This is probably Ok.
  
  applycal(vis = 'uid___A002_Xace764_Xa09.ms',
    field = '2',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_Xace764_Xa09.ms.tsys', 'uid___A002_Xace764_Xa09.ms.wvr', 'uid___A002_Xace764_Xa09.ms.antpos'],
    gainfield = ['3', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  applycal(vis = 'uid___A002_Xace764_Xa09.ms',
    field = '3',
    spw = '17,19,21,23',
    gaintable = ['uid___A002_Xace764_Xa09.ms.tsys', 'uid___A002_Xace764_Xa09.ms.wvr', 'uid___A002_Xace764_Xa09.ms.antpos'],
    gainfield = ['3', '', ''],
    interp = 'linear,linear',
    spwmap = [tsysmap,[],[]],
    calwt = True,
    flagbackup = False)
  
  
  
  if applyonly != True: es.getCalWeightStats('uid___A002_Xace764_Xa09.ms') 
  

# Split out science SPWs and time average
mystep = 8
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split') 
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.flagversions') 
  
  split(vis = 'uid___A002_Xace764_Xa09.ms',
    outputvis = 'uid___A002_Xace764_Xa09.ms.split',
    datacolumn = 'corrected',
    spw = '17,19,21,23',
    keepflags = True)
  
  

print "# Calibration"

# Listobs, and save original flags
mystep = 9
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.listobs')
  listobs(vis = 'uid___A002_Xace764_Xa09.ms.split',
    listfile = 'uid___A002_Xace764_Xa09.ms.split.listobs')
  
  
  if not os.path.exists('uid___A002_Xace764_Xa09.ms.split.flagversions/Original.flags'):
    flagmanager(vis = 'uid___A002_Xace764_Xa09.ms.split',
      mode = 'save',
      versionname = 'Original')
  
  

# Initial flagging
mystep = 10
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  # Flagging shadowed data
  
  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'shadow',
    flagbackup = False)
  
  # Flagging edge channels
  
  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'manual',
    spw = '0:0~7;120~127,1:0~7;120~127,2:0~7;120~127,3:0~7;120~127',
    flagbackup = False)
  

  # Flag DA44, DA47, DA51, DV01, DV14 and DV16 where amplitude
  # drops are noticable likely due to phase variations >20deg 
  #over 'int' time causing de-correlation
  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'manual',
    antenna='DA44,DA51',
    timerange='04:31:48~04:31:50',
    flagbackup = False)

  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'manual',
    antenna='DA47',
    timerange='04:33:11.4~04:33:11.7',
    flagbackup = False)

  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'manual',
    antenna='DV01',
    timerange='04:30:50~04:30:53,04:31:48~04:31:49.5',
    flagbackup = False)

  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'manual',
    antenna='DV14',
    timerange='04:31:18~04:32:20',
    flagbackup = False)


  flagdata(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'manual',
    antenna='DV06',
    timerange='04:31:46~04:31:52',
    flagbackup = False)


# Putting a model for the flux calibrator(s)
mystep = 11
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  setjy(vis = 'uid___A002_Xace764_Xa09.ms.split',
    standard = 'manual',
    field = 'J0510+1800',
    fluxdensity = [4.29452, 0, 0, 0],
    spix = -0.134813,
    reffreq = '139.846GHz')
  
  

# Save flags before bandpass cal
mystep = 12
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'save',
    versionname = 'BeforeBandpassCalibration')
  
  

# Bandpass calibration
mystep = 13
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.ap_pre_bandpass') 
  
  gaincal(vis = 'uid___A002_Xace764_Xa09.ms.split',
    caltable = 'uid___A002_Xace764_Xa09.ms.split.ap_pre_bandpass',
    field = '0', # J0510+1800
    spw = '0:48~80,1:48~80,2:48~80,3:48~80',
    scan = '1,3',
    solint = 'int',
    refant = 'DV19',
    calmode = 'p')
  
  if applyonly != True: es.checkCalTable('uid___A002_Xace764_Xa09.ms.split.ap_pre_bandpass', msName='uid___A002_Xace764_Xa09.ms.split', interactive=False) 
  
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.bandpass') 
  bandpass(vis = 'uid___A002_Xace764_Xa09.ms.split',
    caltable = 'uid___A002_Xace764_Xa09.ms.split.bandpass',
    field = '0', # J0510+1800
    scan = '1,3',
    solint = 'inf',
    combine = 'scan',
    refant = 'DV19',
    solnorm = True,
    bandtype = 'B',
    gaintable = 'uid___A002_Xace764_Xa09.ms.split.ap_pre_bandpass')
  
  if applyonly != True: es.checkCalTable('uid___A002_Xace764_Xa09.ms.split.bandpass', msName='uid___A002_Xace764_Xa09.ms.split', interactive=False) 
  

# Save flags before gain cal
mystep = 14
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'save',
    versionname = 'BeforeGainCalibration')
  
  

# Gain calibration
mystep = 15
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.phase_int') 
  gaincal(vis = 'uid___A002_Xace764_Xa09.ms.split',
    caltable = 'uid___A002_Xace764_Xa09.ms.split.phase_int',
    field = '0~2', # J0510+1800,J0431+2037,J0426+2327
    solint = 'int',
    refant = 'DV19',
    gaintype = 'G',
    calmode = 'p',
    gaintable = 'uid___A002_Xace764_Xa09.ms.split.bandpass')
  
  if applyonly != True: es.checkCalTable('uid___A002_Xace764_Xa09.ms.split.phase_int', msName='uid___A002_Xace764_Xa09.ms.split', interactive=False) 
  
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.ampli_inf') 
  gaincal(vis = 'uid___A002_Xace764_Xa09.ms.split',
    caltable = 'uid___A002_Xace764_Xa09.ms.split.ampli_inf',
    field = '0~2', # J0510+1800,J0431+2037,J0426+2327
    solint = 'inf',
    refant = 'DV19',
    gaintype = 'T',
    calmode = 'a',
    gaintable = ['uid___A002_Xace764_Xa09.ms.split.bandpass', 'uid___A002_Xace764_Xa09.ms.split.phase_int'])
  
  if applyonly != True: es.checkCalTable('uid___A002_Xace764_Xa09.ms.split.ampli_inf', msName='uid___A002_Xace764_Xa09.ms.split', interactive=False) 
  
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.flux_inf') 
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.fluxscale') 
  mylogfile = casalog.logfile()
  casalog.setlogfile('uid___A002_Xace764_Xa09.ms.split.fluxscale')
  
  fluxscaleDict = fluxscale(vis = 'uid___A002_Xace764_Xa09.ms.split',
    caltable = 'uid___A002_Xace764_Xa09.ms.split.ampli_inf',
    fluxtable = 'uid___A002_Xace764_Xa09.ms.split.flux_inf',
    reference = '0') # J0510+1800
  
  casalog.setlogfile(mylogfile)
  
  if applyonly != True: es.fluxscale2(caltable = 'uid___A002_Xace764_Xa09.ms.split.ampli_inf', removeOutliers=True, msName='uid___A002_Xace764_Xa09.ms', writeToFile=True, preavg=10000)
  
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.phase_inf') 
  gaincal(vis = 'uid___A002_Xace764_Xa09.ms.split',
    caltable = 'uid___A002_Xace764_Xa09.ms.split.phase_inf',
    field = '0~1', # J0510+1800,J0431+2037
    solint = 'inf',
    refant = 'DV19',
    gaintype = 'G',
    calmode = 'p',
    gaintable = 'uid___A002_Xace764_Xa09.ms.split.bandpass')
  
  if applyonly != True: es.checkCalTable('uid___A002_Xace764_Xa09.ms.split.phase_inf', msName='uid___A002_Xace764_Xa09.ms.split', interactive=False) 
  

# Save flags before applycal
mystep = 16
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_Xace764_Xa09.ms.split',
    mode = 'save',
    versionname = 'BeforeApplycal')
  
  

# Application of the bandpass and gain cal tables
mystep = 17
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  for i in ['0']: # J0510+1800
    applycal(vis = 'uid___A002_Xace764_Xa09.ms.split',
      field = str(i),
      gaintable = ['uid___A002_Xace764_Xa09.ms.split.bandpass', 'uid___A002_Xace764_Xa09.ms.split.phase_int', 'uid___A002_Xace764_Xa09.ms.split.flux_inf'],
      gainfield = ['', i, i],
      interp = 'linear,linear',
      calwt = True,
      flagbackup = False)
  
  applycal(vis = 'uid___A002_Xace764_Xa09.ms.split',
    field = '1,2~3', # HL Tau,J0426+2327
    gaintable = ['uid___A002_Xace764_Xa09.ms.split.bandpass', 'uid___A002_Xace764_Xa09.ms.split.phase_inf', 'uid___A002_Xace764_Xa09.ms.split.flux_inf'],
    gainfield = ['', '1', '1'], # J0431+2037
    interp = 'linear,linear',
    calwt = True,
    flagbackup = False)
  

# Split out corrected column
mystep = 18
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.cal') 
  os.system('rm -rf uid___A002_Xace764_Xa09.ms.split.cal.flagversions') 
  
  listOfIntents = ['CALIBRATE_BANDPASS#ON_SOURCE',
   'CALIBRATE_FLUX#ON_SOURCE',
   'CALIBRATE_PHASE#ON_SOURCE',
   'CALIBRATE_WVR#AMBIENT',
   'CALIBRATE_WVR#HOT',
   'CALIBRATE_WVR#OFF_SOURCE',
   'CALIBRATE_WVR#ON_SOURCE',
   'OBSERVE_CHECK_SOURCE#ON_SOURCE',
   'OBSERVE_TARGET#ON_SOURCE']
  
  split(vis = 'uid___A002_Xace764_Xa09.ms.split',
    outputvis = 'uid___A002_Xace764_Xa09.ms.split.cal',
    datacolumn = 'corrected',
    intent = ','.join(listOfIntents),
    keepflags = True)
  
  

# Save flags after applycal
mystep = 19
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  
  flagmanager(vis = 'uid___A002_Xace764_Xa09.ms.split.cal',
    mode = 'save',
    versionname = 'AfterApplycal')
  
  

